# remirepo spec file for php-pecl-seassnowflake
#
# Copyright (c) 2021-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-seassnowflake
%else
%global _root_libdir %{_libdir}
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global proj_name  SeasSnowflake
%global pecl_name  SeasSnowflake
%global rpm_name   seassnowflake
%global with_tests 0%{!?_without_tests:1}
%global ini_name   40-%{pecl_name}.ini

Summary:        PHP Extension for Distributed unique ID generator
Name:           %{?scl_prefix}php-pecl-%{rpm_name}
Version:        1.0.0
Release:        3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP
URL:            https://pecl.php.net/package/%{proj_name}
Source0:        https://pecl.php.net/get/%{proj_name}-%{version}.tgz

Patch0:         https://patch-diff.githubusercontent.com/raw/SeasX/SeasSnowflake/pull/3.patch
Patch1:         https://patch-diff.githubusercontent.com/raw/SeasX/SeasSnowflake/pull/5.patch
Patch2:         https://patch-diff.githubusercontent.com/raw/SeasX/SeasSnowflake/pull/6.patch
Patch3:         https://patch-diff.githubusercontent.com/raw/SeasX/SeasSnowflake/pull/9.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
# Upstream states 5.4 but seems badly supported
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}


%description
SeasSnowflake is a distributed unique ID generator inspired by
Twitter's Snowflake [1].

[1] https://blog.twitter.com/engineering/en_us/a/2010/announcing-snowflake

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{proj_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
find . -type f -exec chmod -x {} \;
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

: Sanity check, really often broken
extver=$(sed -n '/#define PHP_SEASSNOWFLAKE_VERSION /{s/.* "//;s/".*$//;p}' php_SeasSnowflake.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-SeasSnowflake \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-SeasSnowflake \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# No useful test in tests directory

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Sep 15 2022 Remi Collet <remi@remirepo.net> - 1.0.0-3
- add patch for PHP 8.2 from
  https://github.com/SeasX/SeasSnowflake/pull/9

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.0.0-2
- rebuild for 8.1.0RC1

* Wed Aug 25 2021 Remi Collet <remi@remirepo.net> - 1.0.0-1
- initial package, version 1.0.0 (stable)
- open https://github.com/SeasX/SeasSnowflake/pull/3 - fix test
- open https://github.com/SeasX/SeasSnowflake/pull/4 - exec perm
- open https://github.com/SeasX/SeasSnowflake/pull/5 - PHP 5
- open https://github.com/SeasX/SeasSnowflake/pull/6 - arginfo
